@@ -302,8 +302,8 @@ class TestIuseCheck(IUSE_Options, misc.ReportTestCase):
         use_addon = addons.UseAddon(options)
         return self.check_kls(options, use_addon=use_addon)
 
-    def mk_pkg(self, iuse=""):
-        return misc.FakePkg("dev-util/diffball-0.7.1", data={"IUSE": iuse})
+    def mk_pkg(self, iuse=''):
+        return misc.FakePkg('dev-util/diffball-0.7.1', data={'IUSE': iuse, 'EAPI': '1'})
 
     def test_known_iuse(self, check):
         self.assertNoReport(check, self.mk_pkg('foo bar'))
@@ -322,8 +322,7 @@ class TestIuseCheck(IUSE_Options, misc.ReportTestCase):
         assert 'x86' in str(r)
 
     def test_invalid_iuse(self, check):
-        chars = ['+', '-', '_', '@']
-        for flag in (chars + [f'{c}flag' for c in chars]):
+        for flag in ('+', '-', '@', '_'):
             r = self.assertReport(check, self.mk_pkg(f'foo {flag}'))
             assert isinstance(r, metadata.InvalidUseFlags)
             assert r.flags == (flag,)
@@ -750,9 +749,8 @@ class TestLicenseCheck(use_based(), misc.ReportTestCase):
 
     def test_single_missing(self):
         r = self.assertReport(self.mk_check(), self.mk_pkg("foo"))
-        assert isinstance(r, metadata.MissingLicenseFile)
+        assert isinstance(r, metadata.UnknownLicense)
         assert r.licenses == ('foo',)
-        assert 'no matching license file: foo' in str(r)
 
     def test_multiple_existing(self):
         chk = self.mk_check(['foo', 'foo2'])
@@ -762,9 +760,8 @@ class TestLicenseCheck(use_based(), misc.ReportTestCase):
     def test_multiple_missing(self):
         chk = self.mk_check(['foo', 'foo2'])
         r = self.assertReport(chk, self.mk_pkg('|| ( foo foo3 foo4 )'))
-        assert isinstance(r, metadata.MissingLicenseFile)
+        assert isinstance(r, metadata.UnknownLicense)
         assert r.licenses == ('foo3', 'foo4')
-        assert 'no matching license files: foo3, foo4' in str(r)
 
     def test_unlicensed_categories(self):
         check = self.mk_check(['foo'])
@@ -841,8 +838,8 @@ class TestDependencyCheck(use_based(), misc.ReportTestCase):
     check_kls = metadata.DependencyCheck
 
     def mk_pkg(self, attr, depset='', eapi='0', iuse=''):
-        if attr == 'BDEPEND':
-            eapi = '7'
+        eapi_attr_map = {'BDEPEND': '7', 'IDEPEND': '8'}
+        eapi = eapi_attr_map.get(attr, eapi)
         return misc.FakePkg(
             'dev-util/diffball-2.7.1',
             data={'EAPI': eapi, 'IUSE': iuse, attr: depset})
@@ -994,8 +991,8 @@ class TestOutdatedBlockersCheck(misc.ReportTestCase):
         # initialize child repo
         self.child_git_repo = make_git_repo()
         self.child_git_repo.run(['git', 'remote', 'add', 'origin', self.parent_git_repo.path])
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
-        self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
+        self.child_git_repo.run(['git', 'remote', 'set-head', 'origin', 'main'])
         self.child_repo = make_repo(self.child_git_repo.path)
 
     def init_check(self, options=None, future=0):
@@ -1035,7 +1032,7 @@ class TestOutdatedBlockersCheck(misc.ReportTestCase):
 
     def test_outdated_blockers(self):
         self.parent_git_repo.remove_all('cat/pkg')
-        self.child_git_repo.run(['git', 'pull', 'origin', 'master'])
+        self.child_git_repo.run(['git', 'pull', 'origin', 'main'])
         self.child_repo.create_ebuild('cat/pkg-1', depend='!!=cat/pkg-0*')
         self.child_git_repo.add_all('cat/pkg: version bump to 1')
 
